import { TrackerPluginInterface, TrackerValidationRuleInterface, TrackerInterface, TrackerEvent } from '@objectiv/tracker-core';

/**
 * The HttpContext Plugin gathers the current URL using the Location API.
 * It implements the `initialize` lifecycle method. This ensures the Context is generated when the tracker is created.
 */
declare class HttpContextPlugin implements TrackerPluginInterface {
    readonly pluginName = "HttpContextPlugin";
    readonly validationRules: TrackerValidationRuleInterface[];
    /**
     * The constructor is responsible for initializing validation rules.
     */
    constructor();
    /**
     * Generate an HttpContext.
     */
    initialize(tracker: TrackerInterface): void;
    /**
     * If the Plugin is usable runs all validation rules.
     */
    validate(event: TrackerEvent): void;
    /**
     * Make this plugin usable only on web, eg: Document and Navigation APIs are both available
     */
    isUsable(): boolean;
}

export { HttpContextPlugin };
